CEO_to_Worker: CEO-to-Worker Pay Ratio (in general: max-to-median)

View source: R/inequalityMeasure.R

CEO_to_WorkerR Documentation

CEO-to-Worker Pay Ratio (in general: max-to-median)

Description

CEO-to-Worker Pay Ratio - it is a pay ratio between CEO pay and median employee pay.

Usage

CEO_to_Worker(X, W = rep(1, length(X)))

Arguments

X

is a data vector

W

is a vector of weights

Details

CEO-to-Worker Pay Ratio is generalized to any numeric data vector by the following formula:

CEO_to_Worker =\frac{H}{L}

where H is the maximum value and L is the median value. Since 2018, U.S. publicly held corporations have had to annually report the ratio between their CEO and median worker compensation.

Value

The value of maximum-to-median ratio, in particular: CEO-to-Worker Pay Ratio for salary data.

Examples

# Simple example for fake salary data
X=seq.int(5000,15000,1000)
W=11:1
CEO_to_Worker(X,W)

data(Tourism)
# Max-to-median (CEO_to_Worker) for total expenditure with sample weights
X=Tourism$Total_expenditure
W=Tourism$Sample_weight
CEO_to_Worker(X,W)




wINEQ documentation built on April 23, 2026, 5:07 p.m.

Related to CEO_to_Worker in wINEQ...